bayespy.inference.vmp.nodes.gaussian.GaussianGammaISODistribution.plates_to_parent
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISODistribution.plates_to_parent